@@ -171,6 +171,12 @@ def convert_dtype(srcdt, ctx):
                 tgt_dt = h5py.special_dtype(vlen=tgt_base)
             else:
                 tgt_dt = h5pyd.special_dtype(vlen=tgt_base)
+        elif srcdt.kind == 'U':
+            # use vlen for unicode strings
+            if is_h5py(ctx['fout']):
+                tgt_dt = h5py.special_dtype(vlen=str)
+            else:
+                tgt_dt = h5pyd.special_dtype(vlen=str)
         else:
             tgt_dt = srcdt
     return tgt_dt
@@ -292,6 +298,7 @@ def copy_attribute(desobj, name, srcobj, ctx):
 
     msg = "creating attribute {} in {}".format(name, srcobj.name)
     logging.debug(msg)
+
     if ctx["verbose"]:
         print(msg)
 
@@ -452,8 +459,11 @@ def create_dataset(dobj, ctx):
             fletcher32 = dobj.fletcher32
             maxshape = dobj.maxshape
             scaleoffset = dobj.scaleoffset
-
-        fillvalue=get_fillvalue(dobj)
+        # setting the fillvalue is failing in some cases
+        # see: https://github.com/HDFGroup/h5pyd/issues/119
+        # just setting to None for now
+        # fillvalue=get_fillvalue(dobj)
+        fillvalue = None
         dset = fout.create_dataset(
             dobj.name, shape=dobj.shape, dtype=tgt_dtype, chunks=chunks,
             compression=compression, shuffle=shuffle, maxshape=maxshape,
